@@ -361,66 +361,35 @@ class Dependencies:
 
     def _add_media(
             self,
-            root: str,
-            file: str,
-            version: str,
-            archive: str = None,
-            checksum: str = None,
+            values: typing.Sequence[
+                typing.Tuple[
+                    str,    # file
+                    str,    # archive
+                    int,    # bit_depth
+                    int,    # channels
+                    str,    # checksum
+                    float,  # duration
+                    str,    # format
+                    int,    # removed
+                    float,  # sampling_rate
+                    int,    # type
+                    str,    # version
+                ]
+            ],
     ):
-        r"""Add or update media file.
-
-        If you want to update only the version
-        of an unaltered media file,
-        don't specify ``archive`` and ``checksum``.
+        r"""Add media files.
 
         Args:
-            root: root directory
-            file: relative file path
-            archive: archive name without extension
-            checksum: checksum of file
-            version: version string
+            values: list of tuples,
+                where each tuple holds the values of a new media entry
 
         """
-        format = audeer.file_extension(file).lower()
+        df = pd.DataFrame.from_records(
+            values,
+            columns=['file'] + list(define.DEPEND_FIELD_NAMES.values()),
+        ).set_index('file')
 
-        if archive is None:
-            archive = self.archive(file)
-
-        if checksum is None:
-            checksum = self.checksum(file)
-            bit_depth = self.bit_depth(file)
-            channels = self.channels(file)
-            duration = self.duration(file)
-            sampling_rate = self.sampling_rate(file)
-        else:
-            try:
-                path = os.path.join(root, file)
-                bit_depth = audiofile.bit_depth(path)
-                if bit_depth is None:  # pragma: nocover (non SND files)
-                    bit_depth = 0
-                channels = audiofile.channels(path)
-                duration = audiofile.duration(path, sloppy=True)
-                sampling_rate = audiofile.sampling_rate(path)
-            except FileNotFoundError:  # pragma: nocover
-                # If sox or mediafile are not installed
-                # we get a FileNotFoundError error
-                raise RuntimeError(
-                    f"sox and mediainfo have to be installed "
-                    f"to publish '{format}' media files."
-                )
-
-        self._df.loc[file] = [
-            archive,
-            bit_depth,
-            channels,
-            checksum,
-            duration,
-            format,
-            0,  # removed
-            sampling_rate,
-            define.DependType.MEDIA,
-            version,
-        ]
+        self._df = self._df.append(df)
 
     def _add_meta(
             self,
@@ -470,3 +439,50 @@ class Dependencies:
 
         """
         self._df.at[file, 'removed'] = 1
+
+    def _update_media(
+            self,
+            values: typing.Sequence[
+                typing.Tuple[
+                    str,    # file
+                    str,    # archive
+                    int,    # bit_depth
+                    int,    # channels
+                    str,    # checksum
+                    float,  # duration
+                    str,    # format
+                    int,    # removed
+                    float,  # sampling_rate
+                    int,    # type
+                    str,    # version
+                ]
+            ],
+    ):
+        r"""Update media files.
+
+        Args:
+            values: list of tuples,
+                where each tuple holds the new values for a media entry
+
+        """
+        df = pd.DataFrame.from_records(
+            values,
+            columns=['file'] + list(define.DEPEND_FIELD_NAMES.values()),
+        ).set_index('file')
+
+        self._df.loc[df.index] = df
+
+    def _update_media_version(
+            self,
+            files: typing.Sequence[str],
+            version: str,
+    ):
+        r"""Update version of media files.
+
+        Args:
+            files: relative file paths
+            version: version string
+
+        """
+        field = define.DEPEND_FIELD_NAMES[define.DependField.VERSION]
+        self._df.loc[files, field] = version
