@@ -223,6 +223,13 @@ def test_load(format, version):
 
     assert audb.exists(DB_NAME, version=version)
 
+    files_duration = {
+        os.path.join(db_root, file): pd.to_timedelta(
+            audiofile.duration(os.path.join(db_root, file)), unit='s')
+        for file in db.files
+    }
+    assert db._files_duration == files_duration
+
     if version is None:
         resolved_version = audb.latest_version(DB_NAME)
     else:
@@ -257,6 +264,7 @@ def test_load(format, version):
         DB_NAME,
         version=version,
         full_path=True,
+        format=format,
         num_workers=pytest.NUM_WORKERS,
         verbose=False,
     )
@@ -265,6 +273,12 @@ def test_load(format, version):
     for table in db.tables:
         assert os.path.exists(os.path.join(db_root, f'db.{table}.csv'))
 
+    files_duration = {
+        file: pd.to_timedelta(audiofile.duration(file), unit='s')
+        for file in db.files
+    }
+    assert db._files_duration == files_duration
+
 
 @pytest.mark.parametrize(
     'version, media, format',
@@ -408,6 +422,7 @@ def test_load_to(version):
         num_workers=pytest.NUM_WORKERS,
         verbose=False,
     )
+    assert db.root == db_root
 
     if version is None:
         version = audb.latest_version(DB_NAME)
